API Handlers
============

The ``handlers`` module
-----------------------

.. module:: bookstore.handlers

``BookstoreVersionHandler``
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: BookstoreVersionHandler
   :members:
   :show-inheritance:

Jupyter Server extension
~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: load_jupyter_server_extension

This function loads bookstore as a Jupyter Server extension.
